from promptflow import PFClient


package_name = "oeahr_package"


def list_package_tools(raise_error=False):
    """
    List the meta of all tools in the package.
    The key of meta dict is the module name of tools and value is the meta data of the tool.
    """
    # This function is auto generated by pf CLI, please do not modify manually.
    tools = {}
    pf_client = PFClient()
    tools = pf_client._tools._list_tools_in_package(package_name, raise_error=raise_error)
    return tools
